# History

## 0.1.1 (2025-11-04)

* Updated README & docs.
* Add checkpointed ingestion from external sources.

## 0.1.0 (2025-11-03)

* First release on PyPI.
* Ingest bioRxiv preprints with OpenAlex metadata.